@@ -59,9 +59,12 @@ struct _QueenBeeconClass
 {
   HDHomePluginItemClass  parent;
   DBusGConnection *dbus_conn;
-  DBusGProxy *bus_proxy;
+  DBusGProxy	*bus_proxy;
+  gboolean 		dbus_registered;
+  //GMutex 		*config_file_mutex;
 
-  gboolean dbus_registered;
+  gboolean 		housekeeping;
+  gboolean 		settingsOn;
 
   // Signal functions Declarations
   void (*queen_beecon_dbus_sig_content_updated) (QueenBeecon *self, gint exitCode);
